┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/treeviewsidebarpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/treeviewsidebarpage.h')
-rw-r--r--src/treeviewsidebarpage.h15
1 files changed, 13 insertions, 2 deletions
diff --git a/src/treeviewsidebarpage.h b/src/treeviewsidebarpage.h
index 1761d8c2b..045586bcc 100644
--- a/src/treeviewsidebarpage.h
+++ b/src/treeviewsidebarpage.h
@@ -25,6 +25,8 @@
class KDirLister;
class KDirModel;
class KUrl;
+
+class QModelIndex;
class QTreeView;
/**
@@ -42,12 +44,21 @@ protected:
/** @see SidebarPage::activeViewChanged() */
virtual void activeViewChanged();
+ /** @see QWidget::showEvent() */
+ virtual void showEvent(QShowEvent* event);
+
private slots:
/**
* Updates the current position inside the tree to
* \a url.
*/
- void updatePosition(const KUrl& url);
+ void updateSelection(const KUrl& url);
+
+ /**
+ * Updates the URL of the active view to the URL
+ * which is given by the item with the index \a index.
+ */
+ void updateViewUrl(const QModelIndex& index);
private:
/**
@@ -42,12 +44,21 @@ protected:
private slots:
/**
- * Updates the current position inside the tree to
+ * Updates the current selection inside the tree to
* \a url.
*/